@@ -2,7 +2,7 @@ from pathlib import Path
 from subprocess import run, CalledProcessError
 import click
 from making_with_code_cli.helpers import cd
-from making_with_code_cli.cli_setup import WORK_DIR_PERMISSIONS
+from making_with_code_cli.setup.tasks import WORK_DIR_PERMISSIONS
 from making_with_code_cli.styles import (
     address,
     info,
@@ -16,18 +16,13 @@ class GitBackend:
     server and the strategies for completing tasks vary by backend. 
     """
 
-    @classmethod
-    def extend_settings(self, settings):
-        "A hook for git backends to collect additional information from the user"
-        return settings
-
     def __init__(self, settings):
         self.settings = settings
 
     def init_module(self, module, modpath):
         raise NotImplemented()
 
-    def update(self, module, modpath):
+    def update(self, module, modpath, install=True):
         if (modpath / ".git").is_dir():
             with cd(modpath):
                 relpath = self.relative_path(modpath)
@@ -36,7 +31,7 @@ class GitBackend:
                     gitresult = run("git pull", shell=True, check=True, capture_output=True,
                             text=True)
                     click.echo(info(gitresult.stdout))
-                    if Path("pyproject.toml").exists():
+                    if install and Path("pyproject.toml").exists():
                         result = run("poetry install", shell=True, check=True, 
                                 capture_output=True, text=True)
                         click.echo(info(result.stdout, preformatted=True))
